# MySQL TSV

This library provides functionality for reading and producing MySQL compatible
Tab-seperated values files.

Installation: `pip install mysqltsv`

## Documentation
See http://pythonhosted.org/mysqltsv

## Authors
Aaron Halfaker:
* `http://halfaker.info`
